#!/bin/bash

PACKAGE_NAME=libgap-sage

set -e
set -u

usage() {
	echo "Usage: ${0##*/} --upstream-version <ver> --upstream-commit-id <commit id>"
	exit 1
	}

if [ "$#" != "4" ]; then
	usage
fi
if [  "$1" != "--upstream-version" -o "$3" != "--upstream-commit-id" ]; then
	usage
fi
UPSTREAM_VERSION="$2"
UPSTREAM_COMMIT_ID=$4

if [ ! -e debian/changelog ]; then
	echo 1>&2 "nonexitent debian/changelog file"
	exit 1
fi

UPSTREAM_REPO="https://bitbucket.org/vbraun/libgap"

DEBIAN_SUFFIX="+g${UPSTREAM_COMMIT_ID}+dsx"

DEBIAN_UVERSION=${UPSTREAM_VERSION}${DEBIAN_SUFFIX}
DEBIAN_ROOTFOLDERNAME="${PACKAGE_NAME}-${DEBIAN_UVERSION}.orig"
DEBIAN_TARBALLXZ="$(realpath ..)/${PACKAGE_NAME}_${DEBIAN_UVERSION}.orig.tar.xz"

GOS_TMPDIR=$(mktemp -d ./get-orig-source-XXXXXX)
GOS_TMPDIR=$(realpath $GOS_TMPDIR)
trap "/bin/rm -rf \"$GOS_TMPDIR\"" QUIT INT EXIT

GOS_WORKING_FOLDER=$(pwd)
cd ${GOS_TMPDIR}

message() {
	echo
	echo "-- -- $1"
	echo
	}


UPSTREAM_GITFOLDER=${GOS_TMPDIR}/GITFOLDER
UPSTREAM_ROOTFOLDER=${GOS_TMPDIR}/unpacked
EXTRA_ROOTFOLDER=${GOS_TMPDIR}/pkgextra

message "Cloning"

git clone git@bitbucket.org:vbraun/libgap.git ${UPSTREAM_GITFOLDER}


message "Fetching extra material"

mkdir ${EXTRA_ROOTFOLDER}
cd ${EXTRA_ROOTFOLDER}
mkdir doc
cd doc
wget https://bitbucket.org/vbraun/libgap/downloads/libGAP.pdf


message "Packaging"

mkdir ${UPSTREAM_ROOTFOLDER}
cd ${UPSTREAM_GITFOLDER}
git archive --prefix="${DEBIAN_ROOTFOLDERNAME}/" --format=tar ${UPSTREAM_COMMIT_ID} | tar -C ${UPSTREAM_ROOTFOLDER} -xf -
git log --date iso ${UPSTREAM_COMMIT_ID} > ${EXTRA_ROOTFOLDER}/GitChangeLog

UPSTREAM_ROOTFOLDER=${UPSTREAM_ROOTFOLDER}/${DEBIAN_ROOTFOLDERNAME}
DEBIAN_ROOTFOLDER=${GOS_TMPDIR}/${DEBIAN_ROOTFOLDERNAME}

cd ${UPSTREAM_ROOTFOLDER}
set -f
## check
if [ ! -e patches/gap-${UPSTREAM_VERSION}.patch ]; then
	echo 1>&2 "nonexitent gap-${UPSTREAM_VERSION}.patch patch"
	exit 1
fi
## wipe out
rm --verbose --force -- .gitignore
rm --verbose --force -- .hgignore
rm --verbose --force -- m4/lt~obsolete.m4
rm --verbose --force -- m4/ltsugar.m4
rm --verbose --force -- m4/ltoptions.m4
rm --verbose --force -- m4/ltversion.m4
rm --verbose --force -- m4/libtool.m4
rm --verbose --force -- test-driver
rm --verbose --force -- depcomp
rm --verbose --force -- compile
rm --verbose --force -- install-sh
rm --verbose --force -- ltmain.sh
rm --verbose --force -- missing
rm --verbose --force -- INSTALL
rm --verbose --force -- config.sub
rm --verbose --force -- config.guess
##
find . -name 'Makefile.in' | xargs --no-run-if-empty rm --verbose --force
rm --verbose --force -- src/config.h.in
rm --verbose --force -- aclocal.m4
rm --verbose --force -- configure
## discard obsolete patches
find patches -type f -a -not -name gap-${UPSTREAM_VERSION}.patch | xargs --no-run-if-empty rm --verbose --force
#### discard non-libGAP source files
## comment: it appears that some modifications were patched, so this part is commented out
##for _g in $(find src/ -type f); do
##	if $(grep --quiet --ignore-case --max-count=1 'libGAP' $_g); then
##	 :
##	else
##		rm --verbose --force -- ${_g}
##	fi
##done
#:
cd ${GOS_WORKING_FOLDER}
set +f
mv ${UPSTREAM_ROOTFOLDER} ${DEBIAN_ROOTFOLDER}

cp -prd ${EXTRA_ROOTFOLDER} ${DEBIAN_ROOTFOLDER}

GOS_TARBALL="${GOS_TMPDIR}/repacked.tar"
GOS_TARBALLXZ="${GOS_TARBALL}.xz"
( cd "${GOS_TMPDIR}" && \
	find -L "${DEBIAN_ROOTFOLDERNAME}" -xdev -type f -print | sort | \
	tar -T-  --owner=root --group=root --mode=a+rX --create --file "${GOS_TARBALL}" \
	)
xz -9e < "${GOS_TARBALL}" > "${GOS_TARBALLXZ}"
mv "${GOS_TARBALLXZ}" "${DEBIAN_TARBALLXZ}"


message "Testing ${DEBIAN_TARBALLXZ##*/}"

xz --verbose --test ${DEBIAN_TARBALLXZ}

message "Printing information about ${DEBIAN_TARBALLXZ##*/}"

xz --verbose --list ${DEBIAN_TARBALLXZ}


message "Quitting"

##
## eos
